==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/tr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Belirtilen ad çok uzun",
    "The given web address is too long" : "Belirtilen site adresi çok uzun",
    "The given web address is not a valid URL" : "Belirtilen site adresi geçersiz",
    "The given legal notice address is too long" : "Belirtilen yasal bildirim adresi çok uzun",
    "The given legal notice address is not a valid URL" : "Belirtilen yasal bildirim adresi geçersiz",
    "The given privacy policy address is too long" : "Belirtilen kişisel gizliliğin korunması ilkesi adresi çok uzun",
    "The given privacy policy address is not a valid URL" : "Belirtilen gizlilik ilkesi adresi geçersiz",
    "The given slogan is too long" : "Belirtilen slogan çok uzun",
    "The given color is invalid" : "Belirtilen renk geçersiz",
    "Disable-user-theming should be true or false" : "Disable-user-theming seçeneği true ya da false olmalıdır",
    "Saved" : "Kaydedildi",
    "Invalid app given" : "Belirtilen uygulama geçersiz",
    "Invalid type for setting \"defaultApp\" given" : "belirtilen \"defaultApp\" ayarı türü geçersiz ",
    "Invalid setting key" : "Ayar tuşu geçersiz",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Geçici klasör bulunamadı",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "No file uploaded" : "Henüz bir dosya yüklenmemiş",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Zaten özel bir tema kullanıyorsunuz. Tema uygulaması ayarları bu değer ile değiştirilebilir.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
    "PHP Imagick module" : "PHP Imagick modülü",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Tema uygulamasında olmasına rağmen \"imagick\" PHP modülü kullanıma alınmamış. Favicon oluşturma işleminin doğru çalışması için bu modülü kurmanız ve kullanıma almanız gerekir.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Bu kopyadaki PHP \"imagick\" modülünde SVG desteği yok. Daha iyi başarım ve uyumluluk için bu modülün kurulması önemle önerilir.",
    "Dark theme with high contrast mode" : "Koyu tema ve yüksek renk karşıtlığı kipi",
    "Enable dark high contrast mode" : "Koyu yüksek renk karşıtlığı kipi kullanılsın",
    "Similar to the high contrast mode, but with dark colours." : "Yüksek renk karşıtlığı kipine benzer ancak koyu renkleri kullanır.",
    "Dark theme" : "Koyu tema",
    "Enable dark theme" : "Koyu tema kullanılsın",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Koyu tema genel aydınlık ve parlaklığı azaltarak gözlerinizi dinlendirir.",
    "System default theme" : "Varsayılan sistem teması",
    "Enable the system default" : "Sistem varsayılanı kullanılsın",
    "Using the default system appearance." : "Varsayılan sistem görünümü kullanılıyor.",
    "Dyslexia font" : "Disleksik yazı türü",
    "Enable dyslexia font" : "Disleksik yazı türü kullanılsın",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "High contrast mode" : "Yüksek renk karşıtlığı kipi",
    "Enable high contrast mode" : "Yüksek renk karşıtlığı kipi kullanılsın",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlığı kipi gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Light theme" : "Açık tema",
    "Enable the default light theme" : "Varsayılan açık tema kullanılsın",
    "The default light appearance." : "Varsayılan açık renkli görünüm.",
    "Legal notice" : "Yasal bildirim",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Adjust the Nextcloud theme" : "Nextcloud temasını ayarla",
    "Name" : "Ad",
    "Web link" : "Site bağlantısı",
    "a safe home for all your data" : "verileriniz için güvenli bir barınak",
    "Slogan" : "Slogan",
    "Primary color" : "Birincil renk",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Birincil renk, önemli düğmeler gibi ögeleri vurgulamak için kullanılır. Geçerli renk temasına bağlı olarak biraz değiştirilebilir.",
    "Legal notice link" : "Yasal bildirim bağlantısı",
    "Privacy policy link" : "Gizlilik ilkesi bağlantısı",
    "Header logo" : "Üst bilgi logosu",
    "Upload new header logo" : "Yeni üst bilgi logosu yükle",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Yeni favicon yükle",
    "User settings" : "Kullanıcı ayarları",
    "Disable user theming" : "Kullanıcı teması kullanımdan kaldırılsın",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Kopyanızı seçip özelleştirebilmenize rağmen, kullanıcılar arka planlarını ve renklerini değiştirebilir. Özelleştirmenizi dayatmak istiyorsanız, bu seçeneği kullanıma alabilirsiniz.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temalar kullandığınız kopyanın ve desteklenen istemcilerin genel görünümün kolayca değiştirilmesini sağlar. Tüm kullanıcılara görüntülenir.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Arka plan görseli yerine düz bir arka plan rengi de yapılandırabilirsiniz. Arka plan görseli kullanıyorsanız bu rengi değiştirmek uygulama menüsü simgelerinin rengini etkiler.",
    "Background color" : "Arka plan rengi",
    "Upload new logo" : "Yeni logo yükle",
    "Logo" : "Logo",
    "Upload new background and login image" : "Yeni arka plan ve oturum açma görselini yükleyin",
    "Background and login image" : "Arka plan ve oturum açma görseli",
    "Advanced options" : "Gelişmiş ayarlar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Yüklenen logo ve renge göre otomatik olarak favicon oluşturulması için ImageMagick PHP eklentisini SVG desteği ile kurun.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. internet sitesi standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {linkstart}İnternet Sitesi İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Bir sorunla karşılaşırsanız, bunları {issuetracker}sorun izleyicimiz{linkend} üzerinden bildirmekten çekinmeyin. Katkıda bulunmak istiyorsanız {designteam}tasarım ekibimize{linkend} katılın!",
    "Unable to apply the setting." : "Ayar uygulanamadı.",
    "Appearance and accessibility settings" : "Görünüm ve erişilebilirlik ayarları",
    "Misc accessibility options" : "Çeşitli erişilebilirlik seçenekleri",
    "Enable blur background filter (may increase GPU load)" : "Arka plan bulanıklaştırılsın (grafik işlemci yükünü artırabilir)",
    "Customization has been disabled by your administrator" : "Özelleştirme yöneticiniz tarafından kullanımdan kaldırılmış",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Önemli ögeleri vurgulamak için bir birincil renk ayarlayın. Birincil düğmeler gibi ögeler için kullanılan renk, erişilebilirlik gereksinimlerini karşılamak üzere ayarlandığında biraz farklılık gösterebilir.",
    "Background and color" : "Arka plan ve renk",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Arka plan varsayılan ayardaki bir görsele, özel olarak yüklenen bir görsele veya düz bir renge ayarlanabilir.",
    "Keyboard shortcuts" : "Kısayol tuşları",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Bazı durumlarda klavye kısayolları erişilebilirlik araçlarına etki edebilir. Aracınıza doğru şekilde odaklanmanızı sağlamak için tüm klavye kısayollarını buradan kullanımdan kaldırabilirsiniz. Bu aynı zamanda uygulamalarda var olan tüm kısayolları da kullanımdan kaldırır.",
    "Disable all keyboard shortcuts" : "Tüm klavye kısayolları kullanımdan kaldırılsın",
    "Current selected app: {app}, position {position} of {total}" : "Seçilmiş geçerli uygulama: {app}, {position} / {total} konumunda",
    "Move up" : "Yukarı taşı",
    "Move down" : "Aşağı taşı",
    "Select a background from your files" : "Dosyalarınızdan bir arka plan seçin",
    "Select background" : "Arka planı seçin",
    "No background has been selected" : "Herhangi bir arka plan seçilmemiş",
    "Custom background" : "Özel arka plan",
    "Plain background" : "Düz arka plan",
    "Default background" : "Varsayılan arka plan",
    "Theme selection is enforced" : "Tema seçimi zorunludur",
    "Could not set the app order" : "Uygulama sırası ayarlanamadı",
    "Could not reset the app order" : "Uygulama sırasını sıfırla",
    "Navigation bar settings" : "Gezinme çubuğu ayarları",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Gezinme çubuğundaki uygulama sırasını yapılandırabilirsiniz. İlk kayıt, oturum açtıktan sonra ya da logoya tıklandığında açılacak varsayılan uygulama olur.",
    "The default app can not be changed because it was configured by the administrator." : "Varsayılan uygulama, yönetici tarafından yapılandırıldığından değiştirilemez.",
    "The app order was changed, to see it in action you have to reload the page." : "Uygulama sırası değiştirildi. Uygulamanın açıldığını görmek için sayfayı yeniden yüklemelisiniz.",
    "Reset default app order" : "Varsayılan uygulama sırasını yükle",
    "Could not set primary color" : "Birincil renk ayarlanamadı",
    "Reset primary color" : "Birincil rengi sıfırla",
    "Could not set global default apps" : "Genel varsayılan uygulamalar ayarlanamadı",
    "Default app" : "Varsayılan uygulama",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Varsayılan uygulama, oturum açtıktan ya da menüdeki logo üzerine tıkladıktan sonra açılır.",
    "Use custom default app" : "Özel varsayılan uygulama kullanılsın",
    "Global default app" : "Genel varsayılan uygulama",
    "Global default apps" : "Genel varsayılan uygulamalar",
    "Default app priority" : "Varsayılan uygulama önceliği",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Bir uygulama bir kullanıcıda kullanıma alınmamışsa, daha düşük öncelikli bir sonraki uygulama kullanılır.",
    "Select a custom color" : "Özel bir renk seçin",
    "Reset to default" : "Varsayılanlara dön",
    "Upload" : "Yükle",
    "Remove background image" : "Arka plan görselini kaldır",
    "Color" : "Renk",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. internet sitesi standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {guidelines}İnternet Sitesi İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    ". Unable to apply the setting." : ". Ayar uygulanamadı.",
    "Background" : "Arka plan",
    "Set a custom background" : "Özel bir arka plan ayarlayın",
    "Change color" : "Rengi değiştir",
    "No background" : "Arka plan olmasın"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/tr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Belirtilen ad çok uzun",
    "The given web address is too long" : "Belirtilen site adresi çok uzun",
    "The given web address is not a valid URL" : "Belirtilen site adresi geçersiz",
    "The given legal notice address is too long" : "Belirtilen yasal bildirim adresi çok uzun",
    "The given legal notice address is not a valid URL" : "Belirtilen yasal bildirim adresi geçersiz",
    "The given privacy policy address is too long" : "Belirtilen kişisel gizliliğin korunması ilkesi adresi çok uzun",
    "The given privacy policy address is not a valid URL" : "Belirtilen gizlilik ilkesi adresi geçersiz",
    "The given slogan is too long" : "Belirtilen slogan çok uzun",
    "The given color is invalid" : "Belirtilen renk geçersiz",
    "Disable-user-theming should be true or false" : "Disable-user-theming seçeneği true ya da false olmalıdır",
    "Saved" : "Kaydedildi",
    "Invalid app given" : "Belirtilen uygulama geçersiz",
    "Invalid type for setting \"defaultApp\" given" : "belirtilen \"defaultApp\" ayarı türü geçersiz ",
    "Invalid setting key" : "Ayar tuşu geçersiz",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Geçici klasör bulunamadı",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "No file uploaded" : "Henüz bir dosya yüklenmemiş",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Zaten özel bir tema kullanıyorsunuz. Tema uygulaması ayarları bu değer ile değiştirilebilir.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
    "PHP Imagick module" : "PHP Imagick modülü",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Tema uygulamasında olmasına rağmen \"imagick\" PHP modülü kullanıma alınmamış. Favicon oluşturma işleminin yapılabilmesi için bu modülü kurmanız ve kullanıma almanız gerekir.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Bu kopyadaki PHP \"imagick\" modülünde SVG desteği yok. Daha iyi başarım ve uyumluluk için bu modülün kurulması önemle önerilir.",
    "Dark theme with high contrast mode" : "Koyu tema ve yüksek renk karşıtlığı kipi",
    "Enable dark high contrast mode" : "Koyu yüksek renk karşıtlığı kipi kullanılsın",
    "Similar to the high contrast mode, but with dark colours." : "Yüksek renk karşıtlığı kipine benzer ancak koyu renkleri kullanır.",
    "Dark theme" : "Koyu tema",
    "Enable dark theme" : "Koyu tema kullanılsın",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Koyu tema genel aydınlık ve parlaklığı azaltarak gözlerinizi dinlendirir.",
    "System default theme" : "Varsayılan sistem teması",
    "Enable the system default" : "Sistem varsayılanı kullanılsın",
    "Using the default system appearance." : "Varsayılan sistem görünümü kullanılıyor.",
    "Dyslexia font" : "Disleksik yazı türü",
    "Enable dyslexia font" : "Disleksik yazı türü kullanılsın",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic, disleksi nedeniyle sık karşılaşılan sorunları aşmak için geliştirilmiş ücretsiz bir yazı türüdür.",
    "High contrast mode" : "Yüksek renk karşıtlığı kipi",
    "Enable high contrast mode" : "Yüksek renk karşıtlığı kipi kullanılsın",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Yüksek renk karşıtlığı kipi gezinmeyi kolaylaştırır. Görsel kalite azalır ancak netlik artar.",
    "Light theme" : "Açık tema",
    "Enable the default light theme" : "Varsayılan açık tema kullanılsın",
    "The default light appearance." : "Varsayılan açık renkli görünüm.",
    "Legal notice" : "Yasal bildirim",
    "Privacy policy" : "Kişisel gizliliğin korunması ilkesi",
    "Adjust the Nextcloud theme" : "Nextcloud temasını ayarla",
    "Name" : "Ad",
    "Web link" : "Site bağlantısı",
    "a safe home for all your data" : "verileriniz için güvenli bir barınak",
    "Slogan" : "Slogan",
    "Primary color" : "Birincil renk",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Birincil renk, önemli düğmeler gibi ögeleri vurgulamak için kullanılır. Geçerli renk temasına bağlı olarak biraz değiştirilebilir.",
    "Legal notice link" : "Yasal bildirim bağlantısı",
    "Privacy policy link" : "Gizlilik ilkesi bağlantısı",
    "Header logo" : "Üst bilgi logosu",
    "Upload new header logo" : "Yeni üst bilgi logosu yükle",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Yeni favicon yükle",
    "User settings" : "Kullanıcı ayarları",
    "Disable user theming" : "Kullanıcı teması kullanımdan kaldırılsın",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Kopyanızı seçip özelleştirebilmenize rağmen, kullanıcılar arka planlarını ve renklerini değiştirebilir. Özelleştirmenizi zorunlu kılmak istiyorsanız, bu seçeneği açabilirsiniz.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temalar kullandığınız kopyanın ve desteklenen istemcilerin genel görünümün kolayca değiştirilmesini sağlar. Tüm kullanıcılara görüntülenir.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Arka plan görseli yerine düz bir arka plan rengi de yapılandırabilirsiniz. Arka plan görseli kullanıyorsanız bu rengi değiştirmek uygulama menüsü simgelerinin rengini etkiler.",
    "Background color" : "Arka plan rengi",
    "Upload new logo" : "Yeni logo yükle",
    "Logo" : "Logo",
    "Upload new background and login image" : "Yeni arka plan ve oturum açma görselini yükleyin",
    "Background and login image" : "Arka plan ve oturum açma görseli",
    "Advanced options" : "Gelişmiş ayarlar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Yüklenen logo ve renge göre otomatik olarak favicon oluşturulması için ImageMagick PHP eklentisini SVG desteği ile kurun.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. internet sitesi standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {linkstart}İnternet Sitesi İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Bir sorunla karşılaşırsanız, bunları {issuetracker}sorun izleyicimiz{linkend} üzerinden bildirmekten çekinmeyin. Katkıda bulunmak istiyorsanız {designteam}tasarım ekibimize{linkend} katılın!",
    "Unable to apply the setting." : "Ayar uygulanamadı.",
    "Appearance and accessibility settings" : "Görünüm ve erişilebilirlik ayarları",
    "Misc accessibility options" : "Çeşitli erişilebilirlik seçenekleri",
    "Enable blur background filter (may increase GPU load)" : "Arka plan bulanıklaştırılsın (grafik işlemci yükünü artırabilir)",
    "Customization has been disabled by your administrator" : "Özelleştirme özelliği yöneticiniz tarafından kapatılmış",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Önemli ögeleri vurgulamak için bir birincil renk ayarlayın. Birincil düğmeler gibi ögeler için kullanılan renk, erişilebilirlik gereksinimlerini karşılamak üzere ayarlandığında biraz farklılık gösterebilir.",
    "Background and color" : "Arka plan ve renk",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Arka plan varsayılan ayardaki bir görsele, özel olarak yüklenen bir görsele veya düz bir renge ayarlanabilir.",
    "Keyboard shortcuts" : "Kısayol tuşları",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Bazı durumlarda klavye kısayolları erişilebilirlik araçlarına etki edebilir. Aracınıza doğru şekilde odaklanmanızı sağlamak için tüm klavye kısayollarını buradan kullanımdan kaldırabilirsiniz. Bu aynı zamanda uygulamalarda var olan tüm kısayolları da kullanımdan kaldırır.",
    "Disable all keyboard shortcuts" : "Tüm klavye kısayolları kullanımdan kaldırılsın",
    "Current selected app: {app}, position {position} of {total}" : "Seçilmiş geçerli uygulama: {app}, {position} / {total} konumunda",
    "Move up" : "Yukarı taşı",
    "Move down" : "Aşağı taşı",
    "Select a background from your files" : "Dosyalarınızdan bir arka plan seçin",
    "Select background" : "Arka planı seçin",
    "No background has been selected" : "Herhangi bir arka plan seçilmemiş",
    "Custom background" : "Özel arka plan",
    "Plain background" : "Düz arka plan",
    "Default background" : "Varsayılan arka plan",
    "Theme selection is enforced" : "Tema seçimi zorunlu kılınmış",
    "Could not set the app order" : "Uygulama sırası ayarlanamadı",
    "Could not reset the app order" : "Uygulama sırasını sıfırla",
    "Navigation bar settings" : "Gezinme çubuğu ayarları",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Gezinme çubuğundaki uygulama sırasını yapılandırabilirsiniz. İlk kayıt, oturum açtıktan sonra ya da logoya tıklandığında açılacak varsayılan uygulama olur.",
    "The default app can not be changed because it was configured by the administrator." : "Varsayılan uygulama, yönetici tarafından yapılandırıldığından değiştirilemez.",
    "The app order was changed, to see it in action you have to reload the page." : "Uygulama sırası değiştirildi. Uygulamanın açıldığını görmek için sayfayı yeniden yüklemelisiniz.",
    "Reset default app order" : "Varsayılan uygulama sırasını yükle",
    "Could not set primary color" : "Birincil renk ayarlanamadı",
    "Reset primary color" : "Birincil rengi sıfırla",
    "Could not set global default apps" : "Genel varsayılan uygulamalar ayarlanamadı",
    "Default app" : "Varsayılan uygulama",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Varsayılan uygulama, oturum açtıktan ya da menüdeki logo üzerine tıkladıktan sonra açılır.",
    "Use custom default app" : "Özel varsayılan uygulama kullanılsın",
    "Global default app" : "Genel varsayılan uygulama",
    "Global default apps" : "Genel varsayılan uygulamalar",
    "Default app priority" : "Varsayılan uygulama önceliği",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Bir uygulama, bir kullanıcı için kullanıma alınmamışsa, daha düşük öncelikli bir sonraki uygulama kullanılır.",
    "Select a custom color" : "Özel bir renk seçin",
    "Reset to default" : "Varsayılanlara dön",
    "Upload" : "Yükle",
    "Remove background image" : "Arka plan görselini kaldır",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Uygulamalarımızı herkesin kullanabilmesini çok önemsiyoruz. internet sitesi standartlarını izleyerek, işlemlerin fare olmadan da yapılabilmesini ve ekran okuyucular gibi yardımcı yazılımların kullanılabilmesini sağlıyoruz. AAA düzeyinde yüksek renk karşıtlığı teması ile AA düzeyinde {guidelines}İnternet Sitesi İçeriği Erişilebilirlik Kuralları{linkend} 2.1 ile uyumlu olmayı amaçladık.",
    ". Unable to apply the setting." : ". Ayar uygulanamadı."
},
"nplurals=2; plural=(n > 1);");
